@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import textile
 from textile.objects import Block
 
@@ -8,6 +6,7 @@ try:
 except ImportError:
     from ordereddict import OrderedDict
 
+
 def test_block():
     t = textile.Textile()
     result = t.block('h1. foobar baby')
@@ -16,15 +15,14 @@ def test_block():
 
     b = Block(t, "bq", "", None, "", "Hello BlockQuote")
     expect = ('blockquote', OrderedDict(), 'p', OrderedDict(),
-            'Hello BlockQuote')
+              'Hello BlockQuote')
     result = (b.outer_tag, b.outer_atts, b.inner_tag, b.inner_atts, b.content)
     assert result == expect
 
     b = Block(t, "bq", "", None, "http://google.com", "Hello BlockQuote")
-    citation = '{0}1:url'.format(t.uid)
     expect = ('blockquote', OrderedDict([('cite',
-        '{0.uid}{0.refIndex}:url'.format(t))]), 'p', OrderedDict(),
-        'Hello BlockQuote')
+              '{0.uid}{0.refIndex}:url'.format(t))]), 'p', OrderedDict(),
+              'Hello BlockQuote')
     result = (b.outer_tag, b.outer_atts, b.inner_tag, b.inner_atts, b.content)
     assert result == expect
 
@@ -40,6 +38,7 @@ def test_block():
     result = (b.outer_tag, b.outer_atts, b.inner_tag, b.inner_atts, b.content)
     assert result == expect
 
+
 def test_block_tags_false():
     t = textile.Textile(block_tags=False)
     assert t.block_tags is False
@@ -48,6 +47,7 @@ def test_block_tags_false():
     expect = 'test'
     assert result == expect
 
+
 def test_blockcode_extended():
     input = 'bc.. text\nmoretext\n\nevenmoretext\n\nmoremoretext\n\np. test'
     expect = '<pre><code>text\nmoretext\n\nevenmoretext\n\nmoremoretext</code></pre>\n\n\t<p>test</p>'
@@ -55,6 +55,7 @@ def test_blockcode_extended():
     result = t.parse(input)
     assert result == expect
 
+
 def test_blockcode_in_README():
     with open('README.textile') as f:
         readme = ''.join(f.readlines())
@@ -63,6 +64,7 @@ def test_blockcode_in_README():
         expect = ''.join(f.readlines())
     assert result == expect
 
+
 def test_blockcode_comment():
     input = '###.. block comment\nanother line\n\np. New line'
     expect = '\t<p>New line</p>'
@@ -70,6 +72,7 @@ def test_blockcode_comment():
     result = t.parse(input)
     assert result == expect
 
+
 def test_extended_pre_block_with_many_newlines():
     """Extra newlines in an extended pre block should not get cut down to only
     two."""
