@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-import six
 from xml.etree import ElementTree
 
 from textile.regex_strings import (align_re_s, cls_re_s, regex_snippets,
-        table_span_re_s, valign_re_s)
-from textile.utils import encode_html, generate_tag, parse_attributes
+                                   table_span_re_s, valign_re_s, pnct_re_s)
+from textile.utils import generate_tag, parse_attributes
 
 try:
     import regex as re
@@ -15,9 +12,21 @@ except ImportError:
 
 
 class Table(object):
+    caption_re = re.compile(
+        (r'^\|\=(?P<capts>{s}{a}{c})\. '
+         r'(?P<cap>[^\n]*)(?P<row>.*)'
+         .format(**{'s': table_span_re_s, 'a': align_re_s, 'c': cls_re_s})),
+        re.S)
+    colgroup_re = re.compile(
+        r'^\|:(?P<cols>{s}{a}{c}\. .*)'
+        .format(**{'s': table_span_re_s, 'a': align_re_s, 'c': cls_re_s}),
+        re.M)
+    heading_re = re.compile(
+        r'^_(?={0}|{1})'.format(regex_snippets['space'], pnct_re_s))
+
     def __init__(self, textile, tatts, rows, summary):
         self.textile = textile
-        self.attributes = parse_attributes(tatts, 'table')
+        self.attributes = parse_attributes(tatts, 'table', restricted=self.textile.restricted)
         if summary:
             self.attributes.update(summary=summary.strip())
         self.input = rows
@@ -28,27 +37,21 @@ class Table(object):
     def process(self):
         rgrp = None
         groups = []
-        if self.input[-1] == '|': # pragma: no branch
-            self.input = '{0}\n'.format(self.input)
-        split = self.input.split('|\n')
+        split = (
+            re.compile(r'\|{0}*?$'.format(regex_snippets['space']), re.M)
+            .split(self.input))
         for i, row in enumerate([x for x in split if x]):
             row = row.lstrip()
 
             # Caption -- only occurs on row 1, otherwise treat '|=. foo |...'
             # as a normal center-aligned cell.
-            if i == 0 and row[:2] == '|=':
-                captionpattern = (r"^\|\=(?P<capts>{s}{a}{c})\. "
-                                  r"(?P<cap>[^\n]*)(?P<row>.*)".format(**{
-                                      's': table_span_re_s, 'a': align_re_s,
-                                      'c': cls_re_s}))
-                caption_re = re.compile(captionpattern, re.S)
-                cmtch = caption_re.match(row)
-                if cmtch:
-                    caption = Caption(**cmtch.groupdict())
-                    self.caption = '\n{0}'.format(caption.caption)
-                    row = cmtch.group('row').lstrip()
-                    if row == '':
-                        continue
+            cmtch = self.caption_re.match(row)
+            if i == 0 and cmtch:
+                caption = Caption(restricted=self.textile.restricted, **cmtch.groupdict())
+                self.caption = '\n{0}'.format(caption.caption)
+                row = cmtch.group('row').lstrip()
+                if row == '':
+                    continue
 
             # Colgroup -- A colgroup row will not necessarily end with a |.
             # Hence it may include the next row of actual table data.
@@ -60,15 +63,16 @@ class Table(object):
                 colgroup_atts, cols = colgroup_data, None
                 if '|' in colgroup_data:
                     colgroup_atts, cols = colgroup_data.split('|', 1)
-                colgrp = Colgroup(cols, colgroup_atts)
+                colgrp = Colgroup(cols, colgroup_atts, restricted=self.textile.restricted)
                 self.colgroup = colgrp.process()
                 if row == '':
                     continue
 
             # search the row for a table group - thead, tfoot, or tbody
             grpmatchpattern = (r"(:?^\|(?P<part>{v})(?P<rgrpatts>{s}{a}{c})"
-                    r"\.\s*$\n)?^(?P<row>.*)").format(**{'v': valign_re_s, 's':
-                        table_span_re_s, 'a': align_re_s, 'c': cls_re_s})
+                               r"\.\s*$\n)?^(?P<row>.*)").format(
+                                   **{'v': valign_re_s, 's': table_span_re_s,
+                                      'a': align_re_s, 'c': cls_re_s})
             grpmatch_re = re.compile(grpmatchpattern, re.S | re.M)
             grpmatch = grpmatch_re.match(row.lstrip())
 
@@ -79,13 +83,13 @@ class Table(object):
                 if rgrp:
                     groups.append('\n\t{0}'.format(rgrp.process()))
                 rgrp = grptypes[grpmatch.group('part')](grpmatch.group(
-                    'rgrpatts'))
+                    'rgrpatts'), restricted=self.textile.restricted)
             row = grpmatch.group('row')
 
             rmtch = re.search(r'^(?P<ratts>{0}{1}\. )(?P<row>.*)'.format(
                 align_re_s, cls_re_s), row.lstrip())
             if rmtch:
-                row_atts = parse_attributes(rmtch.group('ratts'), 'tr')
+                row_atts = parse_attributes(rmtch.group('ratts'), 'tr', restricted=self.textile.restricted)
                 row = rmtch.group('row')
             else:
                 row_atts = {}
@@ -94,22 +98,23 @@ class Table(object):
             r = Row(row_atts, row)
             for cellctr, cell in enumerate(row.split('|')[1:]):
                 ctag = 'td'
-                if cell.startswith('_'):
+                if self.heading_re.match(cell):
                     ctag = 'th'
 
                 cmtch = re.search(r'^(?P<catts>_?{0}{1}{2}\. )'
-                        '(?P<cell>.*)'.format(table_span_re_s, align_re_s,
-                            cls_re_s), cell, flags=re.S)
+                                  '(?P<cell>.*)'.format(
+                                      table_span_re_s, align_re_s, cls_re_s),
+                                  cell, flags=re.S)
                 if cmtch:
                     catts = cmtch.group('catts')
-                    cell_atts = parse_attributes(catts, 'td')
+                    cell_atts = parse_attributes(catts, 'td', restricted=self.textile.restricted)
                     cell = cmtch.group('cell')
                 else:
                     cell_atts = {}
 
                 if not self.textile.lite:
                     a_pattern = r'(?P<space>{0}*)(?P<cell>.*)'.format(
-                            regex_snippets['space'])
+                        regex_snippets['space'])
                     a = re.search(a_pattern, cell, flags=re.S)
                     cell = self.textile.redcloth_list(a.group('cell'))
                     cell = self.textile.textileLists(cell)
@@ -132,43 +137,41 @@ class Table(object):
         if rgrp:
             groups.append('\n\t{0}'.format(rgrp.process()))
 
-        content = '{0}{1}{2}{3}\n\t'.format(self.caption, self.colgroup,
-                ''.join(groups), ''.join(self.content))
+        content = '{0}{1}{2}{3}\n\t'.format(
+            self.caption, self.colgroup, ''.join(groups), ''.join(self.content))
         tbl = generate_tag('table', content, self.attributes)
         return '\t{0}\n\n'.format(tbl)
 
 
 class Caption(object):
-    def __init__(self, capts, cap, row):
-        self.attributes = parse_attributes(capts)
+    def __init__(self, capts, cap, row, restricted):
+        self.attributes = parse_attributes(capts, restricted=restricted)
         self.caption = self.process(cap)
 
     def process(self, cap):
-        tag = generate_tag('caption', cap, self.attributes)
-        return '\t{0}\n\t'.format(tag)
+        tag = generate_tag('caption', cap.strip(), self.attributes)
+        return '\t{0}'.format(tag)
 
 
 class Colgroup(object):
-    def __init__(self, cols, atts):
+    def __init__(self, cols, atts, restricted):
         self.row = ''
         self.attributes = atts
         self.cols = cols
+        self.restricted = restricted
 
     def process(self):
         enc = 'unicode'
-        if six.PY2: # pragma: no branch
-            enc = 'UTF-8'
 
-        group_atts = parse_attributes(self.attributes, 'col')
+        group_atts = parse_attributes(self.attributes, 'col', restricted=self.restricted)
         colgroup = ElementTree.Element('colgroup', attrib=group_atts)
         colgroup.text = '\n\t'
         if self.cols is not None:
-            has_newline = "\n" in self.cols
             match_cols = self.cols.replace('.', '').split('|')
             # colgroup is the first item in match_cols, the remaining items are
             # cols.
             for idx, col in enumerate(match_cols):
-                col_atts = parse_attributes(col.strip(), 'col')
+                col_atts = parse_attributes(col.strip(), 'col', restricted=self.restricted)
                 ElementTree.SubElement(colgroup, 'col', col_atts)
         colgrp = ElementTree.tostring(colgroup, encoding=enc)
         # cleanup the extra xml declaration if it exists, (python versions
@@ -176,7 +179,8 @@ class Colgroup(object):
         # tab between cols and a newline at the end
         xml_declaration = "<?xml version='1.0' encoding='UTF-8'?>\n"
         colgrp = colgrp.replace(xml_declaration, '')
-        return colgrp.replace('><', '>\n\t<')
+        colgrp = colgrp.replace('><', '>\n\t<')
+        return f"\n\t{colgrp}"
 
 
 class Row(object):
@@ -205,9 +209,9 @@ class Cell(object):
 
 
 class _TableSection(object):
-    def __init__(self, tag, attributes):
+    def __init__(self, tag, attributes, restricted):
         self.tag = tag
-        self.attributes = parse_attributes(attributes)
+        self.attributes = parse_attributes(attributes, restricted=restricted)
         self.rows = []
 
     def process(self):
@@ -215,15 +219,15 @@ class _TableSection(object):
 
 
 class Thead(_TableSection):
-    def __init__(self, attributes):
-        super(Thead, self).__init__('thead', attributes)
+    def __init__(self, attributes, restricted):
+        super(Thead, self).__init__('thead', attributes, restricted)
 
 
 class Tbody(_TableSection):
-    def __init__(self, attributes):
-        super(Tbody, self).__init__('tbody', attributes)
+    def __init__(self, attributes, restricted):
+        super(Tbody, self).__init__('tbody', attributes, restricted)
 
 
 class Tfoot(_TableSection):
-    def __init__(self, attributes):
-        super(Tfoot, self).__init__('tfoot', attributes)
+    def __init__(self, attributes, restricted):
+        super(Tfoot, self).__init__('tfoot', attributes, restricted)
